@@ -20,6 +20,7 @@
 
 #include <config.h>
 
+#include <stdbool.h>
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -362,7 +363,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 	 * The Cherry XX44 reader crashes with a wrong value */
 	if ((0x00 == TxBuffer[7]) || (TxBuffer[7] > 0x07))
 	{
-		DEBUG_INFO2("Correct bEntryValidationCondition (was 0x%02X)",
+		DEBUG_INFO2("Fix bEntryValidationCondition (was 0x%02X)",
 			TxBuffer[7]);
 		TxBuffer[7] = 0x02;
 	}
@@ -376,7 +377,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 		 * CCID message. The only value supported is 01h (display 1 message) */
 		if (0x01 != TxBuffer[8])
 		{
-			DEBUG_INFO2("Correct bNumberMessage for GemPC Pinpad (was %d)",
+			DEBUG_INFO2("Fix bNumberMessage for GemPC Pinpad (was %d)",
 				TxBuffer[8]);
 			TxBuffer[8] = 0x01;
 		}
@@ -385,7 +386,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 		 * and "timeout occured" validation conditions */
 		if (0x02 != TxBuffer[7])
 		{
-			DEBUG_INFO2("Correct bEntryValidationCondition for GemPC Pinpad (was %d)",
+			DEBUG_INFO2("Fix bEntryValidationCondition for GemPC Pinpad (was %d)",
 				TxBuffer[7]);
 			TxBuffer[7] = 0x02;	/* validation key pressed */
 		}
@@ -398,7 +399,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 		int bEntryValidationCondition = ccid_descriptor->gemalto_firmware_features->bEntryValidationCondition;
 		if (TxBuffer[7] & ~bEntryValidationCondition)
 		{
-			DEBUG_INFO2("Correct bEntryValidationCondition (was 0x%02X)",
+			DEBUG_INFO2("Fix bEntryValidationCondition (was 0x%02X)",
 				TxBuffer[7]);
 			TxBuffer[7] &= bEntryValidationCondition;
 		}
@@ -411,7 +412,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 		 * CCID message. The only value supported is 00h (no message) */
 		if (0x00 != TxBuffer[8])
 		{
-			DEBUG_INFO2("Correct bNumberMessage for Dell keyboard (was %d)",
+			DEBUG_INFO2("Fix bNumberMessage for Dell keyboard (was %d)",
 				TxBuffer[8]);
 			TxBuffer[8] = 0x00;
 		}
@@ -429,7 +430,7 @@ RESPONSECODE SecurePINVerify(unsigned int reader_index,
 		tmp = TxBuffer[6];
 		TxBuffer[6] = TxBuffer[5];
 		TxBuffer[5] = tmp;
-		DEBUG_INFO1("Correcting wPINMaxExtraDigit for Dell keyboard");
+		DEBUG_INFO1("Fix wPINMaxExtraDigit for Dell keyboard");
 	}
 #endif
 
@@ -719,7 +720,7 @@ RESPONSECODE SecurePINModify(unsigned int reader_index,
 	 * The Cherry XX44 reader crashes with a wrong value */
 	if ((0x00 == TxBuffer[10]) || (TxBuffer[10] > 0x07))
 	{
-		DEBUG_INFO2("Correct bEntryValidationCondition (was 0x%02X)",
+		DEBUG_INFO2("Fix bEntryValidationCondition (was 0x%02X)",
 			TxBuffer[10]);
 		TxBuffer[10] = 0x02;
 	}
@@ -755,7 +756,7 @@ RESPONSECODE SecurePINModify(unsigned int reader_index,
 		 * and "timeout occured" validation conditions */
 		if (0x02 != TxBuffer[10])
 		{
-			DEBUG_INFO2("Correct bEntryValidationCondition for GemPC Pinpad (was %d)",
+			DEBUG_INFO2("Fix bEntryValidationCondition for GemPC Pinpad (was %d)",
 				TxBuffer[10]);
 			TxBuffer[10] = 0x02;	/* validation key pressed */
 		}
@@ -767,7 +768,7 @@ RESPONSECODE SecurePINModify(unsigned int reader_index,
 		int bEntryValidationCondition = ccid_descriptor->gemalto_firmware_features->bEntryValidationCondition;
 		if (TxBuffer[10] & ~bEntryValidationCondition)
 		{
-			DEBUG_INFO2("Correct bEntryValidationCondition (was 0x%02X)",
+			DEBUG_INFO2("Fix bEntryValidationCondition (was 0x%02X)",
 				TxBuffer[10]);
 			TxBuffer[10] &= bEntryValidationCondition;
 		}
@@ -785,7 +786,7 @@ RESPONSECODE SecurePINModify(unsigned int reader_index,
 		bNumberMessage = TxBuffer[11];
 		if (0x03 != TxBuffer[11])
 		{
-			DEBUG_INFO2("Correct bNumberMessage for GemPC Pinpad (was %d)",
+			DEBUG_INFO2("Fix bNumberMessage for GemPC Pinpad (was %d)",
 				TxBuffer[11]);
 			TxBuffer[11] = 0x03; /* 3 messages */
 		}
@@ -798,7 +799,7 @@ RESPONSECODE SecurePINModify(unsigned int reader_index,
 		 * command. Change it to 0xff which is accepted. */
 		if (0x00 == TxBuffer[11])
 		{
-			DEBUG_INFO1("Correct bNumberMessage for Cherry KC 1000 SC (was 0)");
+			DEBUG_INFO1("Fix bNumberMessage for Cherry KC 1000 SC (was 0)");
 			TxBuffer[11] = 0xff;
 		}
 	}
@@ -934,7 +935,7 @@ RESPONSECODE CmdEscape(unsigned int reader_index,
 	unsigned char RxBuffer[], unsigned int *RxLength, unsigned int timeout)
 {
 	return CmdEscapeCheck(reader_index, TxBuffer, TxLength, RxBuffer, RxLength,
-		timeout, FALSE);
+		timeout, false);
 } /* CmdEscape */
 
 
@@ -946,7 +947,7 @@ RESPONSECODE CmdEscape(unsigned int reader_index,
 RESPONSECODE CmdEscapeCheck(unsigned int reader_index,
 	const unsigned char TxBuffer[], unsigned int TxLength,
 	unsigned char RxBuffer[], unsigned int *RxLength, unsigned int timeout,
-	int mayfail)
+	bool mayfail)
 {
 	unsigned char *cmd_in, *cmd_out;
 	int bSeq;
@@ -2047,10 +2048,14 @@ static RESPONSECODE T0ProcSW1(unsigned int reader_index,
 		in_buf = tmp_buf;
 	}
 	sw2 = *rcv_buf = *in_buf;
-	in_len--;
 	(*rcv_len)++;
 
+#ifdef NO_LOG
+	(void)sw1;
+	(void)sw2;
+#else
 	DEBUG_COMM3("Exit: SW=%02X %02X", sw1, sw2);
+#endif
 
 	return return_value;
 } /* T0ProcSW1 */
