@@ -30,18 +30,6 @@
 #include <config.h>
 #endif
 
-/*
- * Boolean constants
- */
-
-#ifndef TRUE
-#define TRUE	1
-#endif
-
-#ifndef FALSE
-#define FALSE	0
-#endif
-
 /*
  * Type definitions
  */
